Add list of prior objects to a plot
geom_prior_list(
prior_list,
xlim = NULL,
x_seq = NULL,
x_range_quant = NULL,
n_points = 500,
n_samples = 10000,
force_samples = FALSE,
individual = FALSE,
show_figures = if (individual) 1 else NULL,
transformation = NULL,
transformation_arguments = NULL,
transformation_settings = FALSE,
rescale_x = FALSE,
scale_y2 = NULL,
prior_list_mu = NULL,
effect_direction = "positive",
...
)geom_prior_list returns an object of class 'ggplot'.
list of prior distributions
x plotting range
sequence of x coordinates
quantile used for
automatically obtaining x_range
if both x_range and x_seq
are unspecified. Defaults to 0.005
for all but Cauchy, Student-t, Gamma, and
Inverse-gamme distributions that use
0.010.
number of equally spaced points
in the x_range if x_seq is unspecified
number of samples from the prior
distribution if the density cannot be obtained
analytically (or if samples are forced with
force_samples = TRUE)
should prior be sampled instead of obtaining analytic solution whenever possible
should individual densities be returned (e.g., in case of weightfunction)
which figures should be returned in case of
multiple plots are generated. Useful when priors for the omega
parameter are plotted and individual = TRUE.
transformation to be applied to the prior distribution. Either a character specifying one of the prepared transformations:
linear transformation in form of a + b*x
hyperbolic tangent transformation
exponential transformation
, or a list containing the transformation function fun,
inverse transformation function inv, and derivative of the
transformation jac, evaluated on the original support. See examples
for details.
a list with named arguments for
the transformation
boolean indicating whether the
settings the x_seq or x_range was specified on
the transformed support
allows to rescale x-axis in case a weightfunction is plotted.
scaling factor for a secondary axis
list of priors for the mu parameter required when plotting PET-PEESE
direction of the effect for PET-PEESE
regression. Use "positive" (default) for
mu + PET*se + PEESE*se^2 or "negative" for
mu - PET*se - PEESE*se^2.
additional arguments
plot_prior_list() lines_prior_list()