Learn R Programming

BayesTools (version 0.3.0)

phack_pi_null: P-hacking calibration helpers

Description

phack_pi_null() converts the sampled severity alpha to the amount of null probability mass depleted from the source interval. phack_alpha_from_pi_null() applies the inverse calibration. phack_backend_constants() returns the z-scale constants used by the backend.

Usage

phack_pi_null(alpha, form, source, destination, target = 0.025)

phack_alpha_from_pi_null(pi_null, form, source, destination, target = 0.025)

phack_backend_constants(form, source, destination, target = 0.025)

Value

Numeric vector for the calibration helpers and a named list for phack_backend_constants().

Arguments

alpha

p-hacking severity parameter.

form

power depletion form, either "linear" or "quadratic".

source

source p-value cut point.

destination

destination p-value cut point.

target

target p-value cut point.

pi_null

null probability mass depleted from the source interval.