Marginal density, marginal distribution function, marginal quantile function and random generation for weight functions.

mdone.sided(x, alpha = NULL, alpha1 = NULL, alpha2 = NULL, log = FALSE)

mdtwo.sided(x, alpha, log = FALSE)

mdone.sided_fixed(x, omega, log = FALSE)

mdtwo.sided_fixed(x, omega, log = FALSE)

rone.sided(n, alpha = NULL, alpha1 = NULL, alpha2 = NULL)

rtwo.sided(n, alpha)

rone.sided_fixed(n, omega)

rtwo.sided_fixed(n, omega)

mpone.sided(
  q,
  alpha = NULL,
  alpha1 = NULL,
  alpha2 = NULL,
  lower.tail = TRUE,
  log.p = FALSE
)

mptwo.sided(q, alpha, lower.tail = TRUE, log.p = FALSE)

mpone.sided_fixed(q, omega, lower.tail = TRUE, log.p = FALSE)

mptwo.sided_fixed(q, omega, lower.tail = TRUE, log.p = FALSE)

mqone.sided(
  p,
  alpha = NULL,
  alpha1 = NULL,
  alpha2 = NULL,
  lower.tail = TRUE,
  log.p = FALSE
)

mqtwo.sided(p, alpha, lower.tail = TRUE, log.p = FALSE)

mqone.sided_fixed(p, omega, lower.tail = TRUE, log.p = FALSE)

mqtwo.sided_fixed(p, omega, lower.tail = TRUE, log.p = FALSE)

Arguments

x, q

vector or matrix of quantiles.

alpha

vector or matrix with concentration parameters for the Dirichlet distribution for a monotonic one.sided or a two.sided weight function.

alpha1

vector or matrix with concentration parameters for the Dirichlet distribution for the expected direction of non-monotonic one.sided of weight function.

alpha2

vector or matrix with concentration parameters for the Dirichlet distribution for the unexpected direction of non-monotonic one.sided of weight function.

log, log.p

logical; if TRUE, probabilities p are given as log(p).

omega

vector or matrix of fixed non-negative relative weights for a one.sided or a two.sided weight function. The first/reference weight must be exactly 1.

n

number of observations.

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).

p

vector of probabilities.

Value

mdone.sided, mdtwo.sided, mdone.sided_fixed, and mdtwo.sided_fixed give the marginal density, mpone.sided, mptwo.sided, mpone.sided_fixed, and mptwo.sided_fixed give the marginal distribution function, mqone.sided, mqtwo.sided, mqone.sided_fixed, and mqtwo.sided_fixed give the marginal quantile function, and rone.sided, rtwo.sided, rone.sided_fixed, and rtwo.sided_fixed generate random deviates.

Examples

# draw samples from a two-sided weight function
rtwo.sided(10, alpha = c(1, 1))
#>       [,1]       [,2]
#>  [1,]    1 0.29002039
#>  [2,]    1 0.33448277
#>  [3,]    1 0.14364780
#>  [4,]    1 0.32997058
#>  [5,]    1 0.93699041
#>  [6,]    1 0.69391624
#>  [7,]    1 0.29964801
#>  [8,]    1 0.31621015
#>  [9,]    1 0.04824246
#> [10,]    1 0.23571261

# draw samples from a monotone one-sided weight function
rone.sided(10, alpha = c(1, 1, 1))
#>       [,1]       [,2]       [,3]
#>  [1,]    1 0.64926698 0.59974495
#>  [2,]    1 0.02665348 0.01504035
#>  [3,]    1 0.93824797 0.69739275
#>  [4,]    1 0.52627879 0.46454111
#>  [5,]    1 0.84026459 0.28494895
#>  [6,]    1 0.28907031 0.01572115
#>  [7,]    1 0.52023337 0.35996305
#>  [8,]    1 0.57176205 0.53499686
#>  [9,]    1 0.89869697 0.43469677
#> [10,]    1 0.75096276 0.09075188

# draw samples from a non-monotone one-sided weight function
rone.sided(10, alpha1 = c(1, 1), alpha2 = c(1, 1))
#>       [,1]       [,2]      [,3]
#>  [1,]    1 0.76056497 0.9175268
#>  [2,]    1 0.05647669 0.2994945
#>  [3,]    1 0.75257832 0.7657803
#>  [4,]    1 0.30490697 0.9624643
#>  [5,]    1 0.71147467 0.9204233
#>  [6,]    1 0.64726949 0.6498803
#>  [7,]    1 0.72820127 0.7454558
#>  [8,]    1 0.30995976 0.3990243
#>  [9,]    1 0.76593092 0.8549241
#> [10,]    1 0.98010818 0.9831307