Creates model summary based on a model objects or provides estimates table for a runjags fit.
model_summary_table(
model,
model_description = NULL,
title = NULL,
footnotes = NULL,
warnings = NULL,
remove_spike_0 = TRUE,
short_name = FALSE,
formula_prefix = TRUE,
remove_parameters = NULL
)runjags_estimates_table(
fit,
transformations = NULL,
title = NULL,
footnotes = NULL,
warnings = NULL,
conditional = FALSE,
probs = c(0.025, 0.5, 0.975),
remove_spike_0 = TRUE,
transform_factors = FALSE,
transform_orthonormal = FALSE,
formula_prefix = TRUE,
remove_inclusion = FALSE,
remove_parameters = NULL,
remove_formulas = NULL,
keep_parameters = NULL,
keep_formulas = NULL,
return_samples = FALSE,
transform_scaled = FALSE,
remove_diagnostics = FALSE,
diagnostic_columns = getOption("BayesTools.JAGS_estimates_diagnostic_columns", if
(remove_diagnostics) "none" else "all")
)
runjags_inference_table(
fit,
title = NULL,
footnotes = NULL,
warnings = NULL,
formula_prefix = TRUE,
logBF = FALSE,
BF01 = FALSE,
BF_diagnostics = FALSE,
BF_diagnostic_columns = getOption("BayesTools.JAGS_BF_diagnostic_columns", if
(BF_diagnostics) "all" else "none")
)
JAGS_estimates_table(
fit,
transformations = NULL,
title = NULL,
footnotes = NULL,
warnings = NULL,
conditional = FALSE,
probs = c(0.025, 0.5, 0.975),
remove_spike_0 = TRUE,
transform_factors = FALSE,
transform_orthonormal = FALSE,
formula_prefix = TRUE,
remove_inclusion = FALSE,
remove_parameters = NULL,
remove_formulas = NULL,
keep_parameters = NULL,
keep_formulas = NULL,
return_samples = FALSE,
transform_scaled = FALSE,
remove_diagnostics = FALSE,
diagnostic_columns = getOption("BayesTools.JAGS_estimates_diagnostic_columns", if
(remove_diagnostics) "none" else "all")
)
JAGS_inference_table(
fit,
title = NULL,
footnotes = NULL,
warnings = NULL,
formula_prefix = TRUE,
logBF = FALSE,
BF01 = FALSE,
BF_diagnostics = FALSE,
BF_diagnostic_columns = getOption("BayesTools.JAGS_BF_diagnostic_columns", if
(BF_diagnostics) "all" else "none")
)
JAGS_summary_table(
model,
model_description = NULL,
title = NULL,
footnotes = NULL,
warnings = NULL,
remove_spike_0 = TRUE,
short_name = FALSE,
formula_prefix = TRUE,
remove_parameters = NULL
)
model_summary_empty_table(
model_description = NULL,
title = NULL,
footnotes = NULL,
warnings = NULL
)
runjags_estimates_empty_table(
probs = c(0.025, 0.5, 0.975),
title = NULL,
footnotes = NULL,
warnings = NULL,
remove_diagnostics = FALSE,
diagnostic_columns = getOption("BayesTools.JAGS_estimates_diagnostic_columns", if
(remove_diagnostics) "none" else "all")
)
runjags_inference_empty_table(
title = NULL,
footnotes = NULL,
warnings = NULL,
logBF = FALSE,
BF01 = FALSE,
BF_diagnostics = FALSE,
BF_diagnostic_columns = getOption("BayesTools.JAGS_BF_diagnostic_columns", if
(BF_diagnostics) "all" else "none")
)
JAGS_estimates_empty_table(
probs = c(0.025, 0.5, 0.975),
title = NULL,
footnotes = NULL,
warnings = NULL,
remove_diagnostics = FALSE,
diagnostic_columns = getOption("BayesTools.JAGS_estimates_diagnostic_columns", if
(remove_diagnostics) "none" else "all")
)
JAGS_inference_empty_table(
title = NULL,
footnotes = NULL,
warnings = NULL,
logBF = FALSE,
BF01 = FALSE,
BF_diagnostics = FALSE,
BF_diagnostic_columns = getOption("BayesTools.JAGS_BF_diagnostic_columns", if
(BF_diagnostics) "all" else "none")
)
stan_estimates_table(
fit,
transformations = NULL,
title = NULL,
footnotes = NULL,
warnings = NULL
)
model_summary_table returns a table with
overview of the fitted model, runjags_estimates_table returns
a table with MCMC estimates, and runjags_estimates_empty_table
returns an empty estimates table. All of the tables are objects of class 'BayesTools_table'.
model object containing a list of priors
and inference object, The inference must be a
named list with information about the model: model number
m_number, marginal likelihood marglik, prior and
posterior probability prior_prob and post_prob,
and model inclusion Bayes factor inclusion_BF
named list with additional description to be added to the table
title to be added to the table
footnotes to be added to the table
warnings to be added to the table
whether prior distributions equal to spike
at 0 should be removed from the prior_list
whether the prior distribution names should be
shortened. Defaults to FALSE.
whether the parameter prefix from formula should
be printed. Defaults to TRUE.
parameters to be removed from the summary.
Can be NULL (default, no removal), a character vector of parameter
names to remove, or TRUE to remove all parameters that are not
part of any formula.
runjags model fit
named list of transformations to be applied to specific parameters
summarizes estimates conditional on being included
in the model for spike and slab priors. Defaults to FALSE.
quantiles for parameter estimates
whether factors with orthonormal/meandif prior distribution should be transformed to differences from the grand mean
(to be depreciated) whether factors with orthonormal prior distributions should be transformed to differences from the grand mean
whether estimates of the inclusion probabilities
should be excluded from the summary table. Defaults to FALSE.
character vector of formula names whose parameters
should be removed from the summary. Defaults to NULL.
character vector of parameter names to keep.
All other parameters will be removed unless they belong to formulas
specified in keep_formulas. Defaults to NULL.
character vector of formula names whose parameters
should be kept. All other parameters will be removed unless they are
specified in keep_parameters. Defaults to NULL.
whether to return the transoformed and formated samples
instead of the table. Defaults to FALSE.
whether coefficients from standardized
continuous predictors should be transformed back to the original
scale. Defaults to FALSE.
whether to exclude MCMC diagnostics (MCMC error,
ESS, R-hat) from the output table. Defaults to FALSE. Setting to
TRUE will exclude diagnostics columns regardless of the
conditional setting.
MCMC diagnostic columns to display in JAGS
estimates tables. Can be "all", "none", TRUE,
FALSE, or a character vector containing any subset of
"MCMC_error", "MCMC_SD_error", "ESS", and
"R_hat". Defaults to the
BayesTools.JAGS_estimates_diagnostic_columns option, or all
diagnostics unless remove_diagnostics = TRUE.
whether the Bayes factor should be on log scale
whether the Bayes factor should be inverted
whether to add MCMC diagnostics for Bayes factors
computed from model indicator frequencies. The Bayes factor error is
reported as a relative Monte Carlo standard error percentage. Defaults to
FALSE.
MCMC diagnostic columns to display in JAGS
inclusion Bayes factor tables. Can be "all", "none",
TRUE, FALSE, or a character vector containing any subset of
"ESS", "MCMC_error", and "BF_error_percent".
Defaults to the BayesTools.JAGS_BF_diagnostic_columns option, or all
diagnostics when BF_diagnostics = TRUE and none otherwise.
For product-space JAGS inclusion Bayes factors, posterior inclusion
probabilities of exactly 0 or 1 cannot produce a finite point estimate of
the model odds ratio. In that case, inclusion BFs marked with "<" or
">" are finite-sample bounds: posterior inclusion probabilities of
0 or 1 were replaced by 1/S or (S - 1)/S, where S is
the number of posterior samples. This is a reporting convention, not an
unbiased finite Bayes-factor estimate. If the prior inclusion probability
is exactly 0 or 1, the inclusion Bayes factor is undefined and reported as
NA, because the corresponding inclusion/exclusion comparison was not
tested.
BayesTools_ensemble_tables