phack_pi_null() converts the sampled severity
alpha to the amount of null probability mass depleted from the source
interval. phack_alpha_from_pi_null() applies the inverse calibration.
phack_backend_constants() returns the z-scale constants used by the
backend.
phack_pi_null(alpha, form, source, destination, target = 0.025)phack_alpha_from_pi_null(pi_null, form, source, destination, target = 0.025)
phack_backend_constants(form, source, destination, target = 0.025)
Numeric vector for the calibration helpers and a named list for
phack_backend_constants().
p-hacking severity parameter.
power depletion form, either "linear" or
"quadratic".
source p-value cut point.
destination p-value cut point.
target p-value cut point.
null probability mass depleted from the source interval.