Plot a list of prior distributions
plot_prior_list(
prior_list,
plot_type = "base",
x_seq = NULL,
xlim = NULL,
x_range_quant = NULL,
n_points = 500,
n_samples = 10000,
force_samples = FALSE,
individual = FALSE,
show_figures = if (individual) 1 else NULL,
transformation = NULL,
transformation_arguments = NULL,
transformation_settings = FALSE,
rescale_x = FALSE,
par_name = NULL,
prior_list_mu = NULL,
effect_direction = "positive",
legend = TRUE,
legend_title = NULL,
legend_labels = NULL,
legend_position = NULL,
...
)list of prior distributions
whether to use a base plot "base"
or ggplot2 "ggplot" for plotting.
sequence of x coordinates
x plotting range
quantile used for
automatically obtaining x_range
if both x_range and x_seq
are unspecified. Defaults to 0.005
for all but Cauchy, Student-t, Gamma, and
Inverse-gamme distributions that use
0.010.
number of equally spaced points
in the x_range if x_seq is unspecified
number of samples from the prior
distribution if the density cannot be obtained
analytically (or if samples are forced with
force_samples = TRUE)
should prior be sampled instead of obtaining analytic solution whenever possible
should individual densities be returned (e.g., in case of weightfunction)
which figures should be returned in case of
multiple plots are generated. Useful when priors for the omega
parameter are plotted and individual = TRUE.
transformation to be applied to the prior distribution. Either a character specifying one of the prepared transformations:
linear transformation in form of a + b*x
hyperbolic tangent transformation
exponential transformation
, or a list containing the transformation function fun,
inverse transformation function inv, and derivative of the
transformation jac, evaluated on the original support. See examples
for details.
a list with named arguments for
the transformation
boolean indicating whether the
settings the x_seq or x_range was specified on
the transformed support
allows to rescale x-axis in case a weightfunction is plotted.
a type of parameter for which the prior is specified. Only relevant if the prior corresponds to a mu parameter that needs to be transformed.
list of priors for the mu parameter required when plotting PET-PEESE
direction of the effect for PET-PEESE
regression. Use "positive" (default) for
mu + PET*se + PEESE*se^2 or "negative" for
mu - PET*se - PEESE*se^2.
whether factor legends should be drawn.
optional title for factor legends.
optional labels for factor legend levels.
optional legend position for factor legends.
additional arguments
plot_prior_list returns either NULL or
an object of class 'ggplot' if plot_type is plot_type = "ggplot".