Learn R Programming

BayesTools (version 0.3.0)

prior_informed_medicine_names: Names of medical subfields from the Cochrane database of systematic reviews

Description

Contains the union of names identifying the individual subfields from the Cochrane database of systematic reviews. Type-specific availability depends on the type argument passed to prior_informed().

Usage

prior_informed_medicine_names

Arguments

Value

returns a character vector with names of medical subfields from Cochrane database of systematic reviews.

Format

An object of class character of length 57.

See Also

prior_informed()

Examples

Run this code
print(prior_informed_medicine_names)

Run the code above in your browser using DataLab