prior_phacking() creates a prior distribution for a mass-preserving p-hacking redistribution kernel. The initial backend supports linear and quadratic power depletion between source and target, with depleted probability mass redistributed between target and destination.

prior_phacking(
  side = "one-sided",
  target = 0.025,
  source = 0.25,
  destination = 0.005,
  form = c("linear", "quadratic"),
  alpha = prior("beta", list(1, 1)),
  report_scale = "pi_null",
  prior_weights = 1
)

Arguments

side

side geometry. Currently only "one-sided" is supported.

target

target p-value cut point.

source

source p-value cut point. Must be larger than target.

destination

destination p-value cut point. Must be smaller than target.

form

power depletion form, either "linear" or "quadratic".

alpha

prior distribution for the p-hacking severity parameter.

report_scale

reporting scale for deterministic summaries.

prior_weights

prior odds associated with a given distribution.

Value

prior_phacking() returns an object of class "prior".